import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "./view"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Окно отображения сообщения при отметке сотрудника
 */
FullscreenDialog {
    id: dialog
    withBottomPanel: params.context !== Context.Authentication
    RowLayout {
        anchors.fill: parent
        spacing: 0
        Rectangle {
            color: Style.parameter("color.modalBackground")
            Layout.fillWidth: true
            Layout.fillHeight: true
            ColumnLayout {
                anchors.centerIn: parent
                Layout.fillWidth: true
                spacing: 0
                Image {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredHeight: 240
                    source: params.success ? Style.parameter("icon.employeeMark.success") : Style.parameter("icon.employeeMark.error")
                    fillMode: Image.PreserveAspectFit
                    Component.onCompleted: mainWindow.scaleImage(this)
                }
                Item {
                    visible: firstMessage.visible
                    Layout.preferredHeight: 16
                }
                BasicLabel {
                    id: firstMessage
                    visible: text.length > 0
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: params.success ? "employeeMarkMessageUserName" : "employeeMarkMessageError"
                    Tr { tr: params.firstMessage }
                }
                Item {
                    Layout.preferredHeight: 16
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: params.success ? "employeeMarkMessageSuccess": "employeeMarkMessageRepeat"
                    Tr { tr: params.secondMessage }
                }
                Item {
                    Layout.preferredHeight: 116
                }
            }
            BasicButton {
                Style.class: "employeeMarkBack"
                anchors {
                    bottom: parent.bottom
                    right: parent.right
                    rightMargin: 24
                    bottomMargin: 24
                }
                width: 124; height: 68
                Tr { code: "employeeMarkButtonBack"; defaultMessage: "Назад" }
                onClicked: {
                    let args = {}
                    args["data"] = false
                    handler.sendAnswer(args)
                }
            }
        }
    }

    DialogHandler { id: handler }
}
