import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "view"
import "view/delegate"

import Artix.Core
import Artix.Gui
import Artix.Models
import Artix.Handlers

/**
 * @brief Диалог выбора или ввода лота
 */
ChoiceList {
    id: root
    dataModel: LotChoiceModel { lots: params.lots }
    listHeader: ChoiceListHeaderDelegate {
        visible: dataModel.rowCount() > 0
        contentItem: Item {
            RowLayout {
                anchors.fill: parent
                spacing: 0
                BasicLabel {
                    Style.class: "lotChoiceDelegate"
                    Layout.minimumWidth: 240
                    Layout.maximumWidth: 240
                    Layout.alignment: Qt.AlignVCenter
                    Tr { code: "lotChoiceArticle"; defaultMessage: "Артикул" }
                }
                Item{ Layout.fillWidth: true }
                BasicLabel {
                    Style.class: "lotChoiceDelegate"
                    Layout.minimumWidth: 96
                    Layout.maximumWidth: 96
                    Layout.alignment: Qt.AlignVCenter
                    Tr { code: "lotChoiceLot"; defaultMessage: "Лот" }
                }
                BasicLabel {
                    Style.class: "lotChoiceDelegate"
                    Layout.minimumWidth: 96
                    Layout.maximumWidth: 96
                    Layout.alignment: Qt.AlignVCenter
                    Tr { code: "lotChoiceProductionDate"; defaultMessage: "Изготовлено" }
                }
            }
        }
    }
    delegate: ChoiceListDelegate {
        contentItem: Item {
            RowLayout {
                anchors.fill: parent
                spacing: 0
                    BasicLabel {
                    id: delegateBarcode
                    Style.class: "lotChoiceDelegate"
                    Layout.minimumWidth: 240
                    Layout.maximumWidth: 240
                    Layout.alignment: Qt.AlignVCenter
                    text: params.barcode
                }
                Item{ Layout.fillWidth: true}
                BasicLabel {
                    id: delegateLot
                    Style.class: "lotChoiceDelegate"
                    Layout.minimumWidth: 96
                    Layout.maximumWidth: 96
                    Layout.alignment: Qt.AlignVCenter
                    text: lot
                }
                BasicLabel {
                    id: delegateProductionDate
                    Style.class: "lotChoiceDelegate"
                    Layout.minimumWidth: 96
                    Layout.maximumWidth: 96
                    Layout.alignment: Qt.AlignVCenter
                    text: date
                }
            }
        }
    }
    titleContent: ColumnLayout {
        spacing: 8
        BasicLabel {
            id: titleLabel
            Style.class: "lotChoiceTitle"
            Layout.fillWidth: true
            Tr { tr: params.title }
        }
        BasicLabel {
            id: goodsItemNameLabel
            Style.class: "lotChoiceGoodsItemName"
            Layout.fillWidth: true
            text: params.goodsItemName
        }
        Item{ Layout.preferredHeight: 8}
        BasicButton {
            Style.class: "lotChoiceInputDate"
            Layout.fillWidth: true
            Layout.preferredHeight: 56
            textLayout {
                fillWidth: true
                fillHeight: true
            }
            horizontalAlignment: Qt.AlignHCenter
            verticalAlignment: Qt.AlignVCenter
            Tr { code: "lotChoiceInputDate"; defaultMessage: "Ввести дату изготовления" }
            onClicked: handler.sendAnswer("inputDate")
        }
        
    }

    DialogHandler { id: handler }

    onAccept: handler.sendAnswer(dataModel.data(selectionModel.currentIndex, LotChoiceModel.LotRole))
    onReject: handler.sendAnswer()
}
