import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Окно сообщения
 */
ModalDialog {
    id: dialog

    property int messageType: params.type
    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: handler.sendAnswer()
        onCancel: handler.sendAnswer()
    }

    implicitWidth: image.visible ? Math.max(defaultWidth, image.width + leftPadding + rightPadding) : defaultWidth

    contentItem: ColumnLayout {
        objectName: "mainLayout"
        id: mainLayout
        spacing: 24
        ColumnLayout {
            objectName: "messageLayout"
            spacing: 16
            Image {
                objectName: "messageBoxIcon"
                id: image
                Layout.alignment: Qt.AlignHCenter
                Layout.maximumWidth: Style.resolution.width * 0.75
                Layout.preferredWidth: paintedWidth
                Layout.preferredHeight: 72
                fillMode: Image.PreserveAspectFit
                Component.onCompleted: mainWindow.scaleImage(this)
                source: {
                    if (dialog.messageType === DialogEnum.Error)
                        return Style.parameter("icon.dialog.error")
                    if (dialog.messageType === DialogEnum.Warning)
                        return Style.parameter("icon.dialog.warning")
                    return Style.parameter("icon.dialog.info")
                }
            }
            BasicLabel {
                objectName: "messageBoxTitle"
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredWidth: mainLayout.width
                horizontalAlignment: Text.AlignHCenter
                Style.class: "messageBoxTitle"
                Tr { tr: dialog.messageType === DialogEnum.Message ? params.message : params.title }
            }
            BasicLabel {
                objectName: "messageBoxMessage"
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredWidth: mainLayout.width
                Layout.maximumHeight: 240
                horizontalAlignment: Text.AlignHCenter
                Style.class: "messageBoxMessage"
                visible: dialog.messageType === DialogEnum.Message ? false : true
                Tr { tr: params.message }
                elide: Text.ElideRight
            }
        }
        BasicButton {
            objectName: "messageBoxButton"
            id: okButton
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 200
            Layout.preferredHeight: 56
            textLayout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
            Style.class: "messageBoxOk"
            visible: !params.hideButton
            Tr { code: "okButton"; defaultMessage: "OK" }
            DialogHandler { id: handler }
            onClicked: handler.sendAnswer()
        }
    }
}
