import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Models
import Artix.View

// Чек на втором экране
BasicView {
    anchors.fill: parent
    id: viewDocument

    property int displayType: qmlMainWindow.displayType

    GridLayout {
        anchors.fill: parent
        rowSpacing: 0
        columnSpacing: 0
        flow: displayType == ViewDisplayType.VerticalReceiptAdvertising || displayType == ViewDisplayType.VerticalAdvertisingReceipt ?
                  GridLayout.TopToBottom : GridLayout.LeftToRight

        AdvertisingBox {
            interactive: false
            Style.class: "viewAdvertisingBox"
            visible: qmlMainWindow.displayType != ViewDisplayType.Receipt
            Layout.fillWidth: {
                switch (displayType) {
                case ViewDisplayType.VerticalReceiptAdvertising:
                case ViewDisplayType.VerticalAdvertisingReceipt:
                case ViewDisplayType.Advertising:
                    return true
                default:
                    return !receipt.visible
                }
            }
            Layout.fillHeight: {
                switch (displayType) {
                case ViewDisplayType.HorizontalReceiptAdvertising:
                case ViewDisplayType.HorizontalAdvertisingReceipt:
                case ViewDisplayType.Advertising:
                    return true
                default:
                    return !receipt.visible
                }
            }
            Layout.row: displayType == ViewDisplayType.VerticalReceiptAdvertising ? 1 : 0
            Layout.column: displayType == ViewDisplayType.HorizontalReceiptAdvertising ? 1 : 0
        }

        GroupBox {
            id: receipt
            Style.class: "viewReceiptBox"
            property bool hidden: false         // чек скрыт по сигналу

            function isReceiptVisible() {
                if (hidden)
                    return false
                switch (qmlMainWindow.displayType) {
                case ViewDisplayType.Changing:
                    return positions.model.positionsCount > 0 && ![DocumentStatus.None, DocumentStatus.Cancel, DocumentStatus.Close]
                                                                    .some(status => status == positions.model.documentStatus)
                case ViewDisplayType.Advertising:
                    return false
                default:
                    return positions.model.positionsCount > 0
                }
            }
            visible: isReceiptVisible()
            Layout.row: displayType == ViewDisplayType.VerticalAdvertisingReceipt ? 1 : 0
            Layout.column: displayType == ViewDisplayType.HorizontalAdvertisingReceipt ? 1 : 0
            Layout.fillHeight: true
            Layout.fillWidth: true
            Layout.minimumWidth: total.width

            Connections {
                target: qmlMainWindow
                function onHideInfoItem() { receipt.hidden = true }
                function onShowInfoItem() { receipt.hidden = false }
            }

            ColumnLayout {
                anchors.fill: parent
                // Заголовок
                RowLayout {
                    spacing: 10 // пространство между элементами
                    BasicLabel {
                        Layout.leftMargin: 24
                        Layout.preferredHeight: 88
                        Style.class: "viewCheckNumber"
                        Tr {
                            code: "viewDocumentTitle"; defaultMessage: "Кассовый чек №%1"
                            args: [positions.model.documentNumber]
                        }
                        verticalAlignment: Label.AlignVCenter
                    }
                    Item {Layout.fillWidth: true}
                    Image {
                        Layout.preferredHeight: 24
                        Layout.preferredWidth: 24
                        fillMode: Image.PreserveAspectFit
                        source: Style.parameter("icon.view.buy")
                    }
                    BasicLabel {
                        Layout.rightMargin: 24
                        Style.class: "viewPositionsCount"
                        text: positions.model.positionsCount
                    }
                }
                Line {
                    Layout.fillWidth: true
                    Layout.preferredHeight: 1
                    color: Style.parameter("color.grayMedium")
                    strokeWidth: 1
                }
                // Позиции
                ListView {
                    id: positions
                    Layout.fillHeight: true
                    Layout.fillWidth: true
                    model: ViewDocumentModel { id: viewDocumentModel }
                    onCountChanged: { positions.positionViewAtEnd() }
                    clip: true
                    delegate: GroupBox {
                        id: position
                        property int labelLeftMargin: 24
                        property int topBottomMargin: viewDocumentModel.showImage ? 28 : 24
                        background: Rectangle {
                             color: number == viewDocumentModel.lastAddedPositionNumber ? Style.parameter("color.greenSelect") : Style.parameter("color.lightBackground")
                             ColorAnimation on color { to: Style.parameter("color.lightBackground"); duration: 300 }
                        }
                        height: viewDocumentModel.showImage ? 168 : 136
                        width: positions.width
                        interactive: false
                        contentItem: RowLayout {
                            anchors.fill: parent
                            spacing: 0
                            Image {
                                Layout.leftMargin: 24
                                Layout.preferredHeight: 120
                                Layout.preferredWidth: 120
                                fillMode: Image.PreserveAspectFit
                                visible: viewDocumentModel.showImage
                                source: viewDocumentModel.showImage ? image : ""
                            }
                            ColumnLayout {
                                RowLayout {
                                    BasicLabel {
                                        Layout.alignment: Qt.AlignTop
                                        Layout.leftMargin: labelLeftMargin
                                        Layout.fillHeight: true
                                        Layout.fillWidth: true
                                        Layout.topMargin: position.topBottomMargin
                                        Style.class: "viewPositionDelegateName"
                                        text: name
                                        elide: Text.ElideRight
                                        maximumLineCount: 3
                                        wrapMode: Text.WordWrap
                                    }
                                    Item {Layout.fillWidth: true}
                                    ColumnLayout {
                                        Layout.alignment: Qt.AlignTop
                                        spacing: 0
                                        BasicLabel {
                                            Layout.preferredWidth: 144
                                            Layout.rightMargin: 24
                                            Layout.topMargin: position.topBottomMargin
                                            Style.class: "viewPositionDelegateDiscountSum"
                                            text: (Utils.moneyIsZero(discountSum) && discount < 1) ? Utils.formatMoneyItem(sum) : Utils.formatMoneyItem(discountSum)
                                            horizontalAlignment: Qt.AlignRight
                                        }
                                        BasicLabel {
                                            Layout.preferredWidth: 144
                                            Layout.rightMargin: 24
                                            Style.class: "viewPositionDelegateSum"
                                            text: Utils.formatMoneyItem(sum)
                                            horizontalAlignment: Qt.AlignRight
                                            visible: discount >= 1
                                        }
                                    }
                                }
                                RowLayout {
                                    BasicLabel {
                                        Layout.bottomMargin: position.topBottomMargin
                                        Layout.leftMargin: labelLeftMargin
                                        Layout.fillHeight: true
                                        Layout.fillWidth: true
                                        Style.class: "viewPositionDelegateQuantity"
                                        text: quantity
                                        verticalAlignment: Label.AlignBottom
                                    }
                                    Item {Layout.fillWidth: true}
                                    ColumnLayout {
                                        Item {Layout.fillHeight: true}
                                        BasicLabel {
                                            Layout.bottomMargin: position.topBottomMargin
                                            Layout.rightMargin: 24
                                            Style.class: "viewPositionDelegateDiscount"
                                            Tr {
                                                code: "viewDocumentPositionDiscount"; defaultMessage: "скидка %1%"
                                                args: [discount]
                                            }
                                            horizontalAlignment: Qt.AlignRight
                                            bottomPadding: 4
                                            leftPadding: 8
                                            rightPadding: 8
                                            topPadding: 4
                                            verticalAlignment: Label.AlignBottom
                                            visible: discount >= 1 
                                        }
                                    }
                                }
                            }
                        }
                        // Разделитель
                        Line {
                            id: sep
                            y: parent.height - strokeWidth
                            width: parent.width
                            color: Style.parameter("color.grayBorder")
                            strokeWidth: 1
                        }
                    }
                }

                // Итого
                RowLayout {
                    id: total
                    Item {Layout.fillWidth: true}
                    GroupBox {
                        Layout.preferredHeight: 144
                        Layout.preferredWidth: 464
                        Style.class: "viewPositionsFooter"
                        padding: 24
                        contentItem: ColumnLayout {
                            spacing: 24
                            RowLayout {
                                BasicLabel {
                                    Style.class: "viewDocumentDiscount"
                                    Tr { code: "viewDocumentDiscountsSum"; defaultMessage: "Сумма скидок" }
                                }
                                Item {Layout.fillWidth: true}
                                BasicLabel {
                                    Style.class: "viewDocumentDiscount"
                                    text: Utils.formatMoneyItem(positions.model.documentDiscountSum)
                                }
                            }
                            RowLayout {
                                BasicLabel {
                                    Layout.fillWidth: true
                                    Style.class: "viewTotal"
                                    Tr { code: "viewDocumentTotal"; defaultMessage: "Итого" }
                                }
                                Item {Layout.fillWidth: true}
                                BasicLabel {
                                    Style.class: "viewTotal"
                                    text: Utils.formatMoneyItem(positions.model.documentSum)
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
