import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui

/**
 * @brief Базовый боковой диалог выбора из списка
 * @param dataModel модель для списка
 * @param selectionModel модель выбора элемента списка (только для чтения)
 * @param delegate делегат списка
 * @param titleContent заголовок диалога (компонент для загрузки)
 * @param titleItem заголовок диалога (загруженный компонент)
 * @param cancelVisible отображение кнопки отмены
 */
SideDialog {
    property alias dataModel: listView.model
    readonly property ItemSelectionModel selectionModel: ItemSelectionModel { model: dataModel }
    property alias listHeader: listView.header
    property alias delegate: listView.delegate
    property alias titleContent: titleLoader.sourceComponent
    // Эти свойства нужны чтобы скрывать Layout с кнопками. Если его не скрывать, когда он пустой, ломается Layout.fillHeight
    property bool cancelVisible: true
    property bool okVisible: selectionModel.hasSelection
    signal accept()
    signal reject()

    property DialogEventFilter eventFilter: DialogEventFilter {
        onCancel: { if (cancelVisible) reject() }
        onOk: { if (okVisible) accept() }
    }

    padding: 0
    contentItem: ColumnLayout {
        spacing: 0
        Loader {
            Layout.leftMargin: 24
            Layout.rightMargin: 24
            Layout.topMargin: 16
            Layout.bottomMargin: 16
            Layout.fillWidth: true
            id: titleLoader
        }
        ListView {
            id: listView
            Layout.fillWidth: true
            Layout.fillHeight: true
            spacing: 1
            clip: true

            // При масштабировании, списки могут отображаться с артефактами.
            // Рендерим с мультисемплированием в нужном разрешении. Не знаю за счет чего, но проблему это решило.
            layer {
                enabled: mainWindow.multisampling
                samples: 2
                textureSize: Qt.size(width * mainWindow.scaleFactor, height * mainWindow.scaleFactor)
            }
        }
        RowLayout {
            visible: okVisible || cancelVisible
            spacing: 16
            Layout.rightMargin: 16
            Layout.topMargin: 24
            Layout.bottomMargin: 24
            Layout.alignment: Qt.AlignRight
            BasicButton {
                id: okButton
                Style.class: "choiceListOk"
                Layout.preferredWidth: 200
                Layout.preferredHeight: 56
                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                horizontalAlignment: Qt.AlignHCenter
                verticalAlignment: Qt.AlignVCenter
                visible: okVisible
                Tr { code: "selectButton"; defaultMessage: "Выбрать" }
                onClicked: accept()
            }
            BasicButton {
                id: cancelButton
                Style.class: "choiceListCancel"
                Layout.preferredWidth: 200
                Layout.preferredHeight: 56
                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                horizontalAlignment: Qt.AlignHCenter
                verticalAlignment: Qt.AlignVCenter
                visible: cancelVisible
                Tr { code: "cancelButton"; defaultMessage: "Отмена" }
                onClicked: reject()
            }
        }
    }
}
