import QtQml.Base
import QtQuick
import QtQuick.VirtualKeyboard

import Artix.Core

/**
 * @brief Встроенная клавиатура
 *
 * @param style объект стиля клавиатуры
 * @param layoutType тип раскладки
 * @param defaultLocale язык по умолчанию
 * @param showCancel отобразить кнопку отмены
 * @param enterEnabled кнопка ввода активна
 * @param enterTr текст на кнопке enter
 */
Item {
    id: root

    property alias style: keyboard.style
    property alias layoutType: keyboard.layoutType
    property string defaultLocale
    property alias showCancel: keyboard.showCancel
    property alias enterEnabled: keyboard.enterEnabled
    property alias enterTr: keyboard.enterTr
    property alias cancelTr: keyboard.cancelTr
    readonly property alias layout: keyboard.layout

    signal enter()      ///< сигнал нажания кнопки ввода
    signal cancel()     ///< сигнал нажания кнопки отмены
    signal hide()       ///< сигнал скрытия всплывающей клавиатуры

    Keyboard {
        id: keyboard
        anchors.fill: parent
        active: true
        layoutType: root.layoutType

        property bool showCancel: false
        property bool enterEnabled: true
        property var enterTr: Utils.makeTr("keyboardEnterButton", "Ввод")
        property var cancelTr: Utils.makeTr("keyboardCancelButton", "Отмена")

        Binding {
            target: keyboard.style
            property: "layoutType"
            value: keyboard.layoutType
        }
        Binding {
            target: keyboard
            property: "inputLocale"
            when: !!root.defaultLocale
            value: root.defaultLocale
        }
        Binding {
            target: keyboard.style
            property: "keyboardDesignWidth"
            value: root.width
        }
        Binding {
            target: keyboard.style
            property: "keyboardDesignHeight"
            value: root.height
        }

        function enter() { root.enter() }
        function cancel() { root.cancel() }
        function hide() { root.hide() }
    }
}
