import QtQuick
import QtQuick.Controls

import Artix.Gui

/**
 * @brief Всплывающая клавиатура
 * @param hidedY значение y в скрытом состоянии
 * @param shownY значение y в отображенном состоянии
 */
Popup {
    id: control
    parent: mainWindow.Overlay.overlay

    property real hidedY: mainWindow.Overlay.overlay.height + control.height * scale
    property real shownY: mainWindow.Overlay.overlay.height - (control.height + mainWindow.footer.height) * scale
    property InlineKeyboard keyboard: keyboard

    x: 0; y: hidedY
    scale: mainWindow.scaleFactor
    width: primaryScreen.geometry.width / scale
    height: 412
    topPadding: 16
    bottomPadding: 24
    closePolicy: Popup.NoAutoClose
    transformOrigin: Item.TopLeft
    contentItem: Item {
        InlineKeyboard {
            id: keyboard
            anchors.horizontalCenter: parent.horizontalCenter
            height: 372
            width: {
                if (["dialpad", "digits", "numbers", "input_digits"].indexOf(layoutType) !== -1)
                    return 256;
                return 960
            }
            layoutType: "main"
        }
    }
    background: Rectangle {
        color: Style.parameter("color.modalBackground")
        // Чтобы фон не прокликивался насквозь
        MouseArea { anchors.fill: parent }
        // Тень
        Rectangle {
            anchors.bottom: parent.top
            width: parent.width
            height: 5
            gradient: Gradient {
                orientation: Gradient.Vertical
                GradientStop { position: 0.0; color: "transparent" }
                GradientStop { position: 1.0; color: Style.parameter("color.shadow") }
            }
            opacity: 0.3
        }
    }
    enter: Transition {
        id: enterTransition
        SmoothedAnimation { id: enterAnimation; velocity: 2000 * scale; property: "y"; to: shownY }
    }
    exit: Transition {
        id: exitTransition
        SmoothedAnimation { id: exitAnimation; velocity: 2000 * scale; property: "y"; to: hidedY }
    }
}
