import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"
import "../"

import Artix.Core
import Artix.Gui

/**
 * @brief Панель ввода даты для панели действий
 */
GridLayout {
    id: root
    rowSpacing: 8
    columnSpacing: 8
    columns: 2
    rows: 3

    signal back()
    signal commit(var action, var args)
    property string text
    property var title: Utils.makeTr("documentOpenInputDateTitle", "Введите дату")
    property var placeholder: Utils.makeTr("documentOpenInputDatePlaceholder", "дд.мм.гг")
    property var action
    readonly property RegularExpressionValidator inputFieldMask: RegularExpressionValidator { regularExpression: /(((0[1-9])|([12][0-9])|(3[01]))\.((0[1-9])|(1[012]))\.((0[0-9])|([1-9][0-9])))/ }
    property var inputTextFixedCursorPosition: false
    property var inputTextHorizontalAlignment: Text.AlignLeft

    readonly property real cellWidth: (width - columnSpacing * (columns - 1)) / columns // Ширина кнопки
    readonly property real cellHeight: (height - rowSpacing * (rows - 1)) / rows        // Высота кнопки

    property FormEventFilter eventFilter: FormEventFilter {
        onOk: accept()
        onCancel: back()
    }

    Item {
        Layout.preferredHeight: cellHeight
        Layout.row: 0
        Layout.column: 0
    }
    BasicButton {
        Style.class: "actionPanelDelegate24px600"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight
        Layout.row: 1
        Layout.column: 1

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonBack"; defaultMessage: "Назад" }
        onClicked: root.commit(root.action, {})
    }
    BasicButton {
        Style.class: "actionPanelDelegateContinue"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight
        Layout.row: 2
        Layout.column: 1
        enabled: root.text.length == 8

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        icon: Style.parameter("icon.actionPanel.arrow")
        Tr { code: "actionPanelButtonAdd"; defaultMessage: "Добавить" }
        onClicked: accept()
    }
    InlineKeyboard {
        Style.class: "actionPanelDelegate"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight * Layout.rowSpan + rowSpacing * (Layout.rowSpan - 1)
        Layout.row: 1
        Layout.rowSpan: 2
        Layout.column: 0
        layoutType: "digits"
    }

    function accept() {
        if (root.text.length != 8)
            return
        let args = {}
        args["data"] = root.text
        args["rawdata"] = root.text
        args["source"] = InputSource.Keyboard
        root.commit(root.action, args)
    }
    onActionChanged: {
        if (action !== undefined) {
            title = Utils.variantToObjectPointer(action).value("title")
        }
    }
}
